Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: ios/chrome/browser/application_context.h

Issue 2893943004: Refactor UKM interface for mojo-ification (Closed)
Patch Set: Fixed contextualsearch Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/ukm/ukm_source.h ('k') | ios/chrome/browser/application_context_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/chrome/browser/application_context.h
diff --git a/ios/chrome/browser/application_context.h b/ios/chrome/browser/application_context.h
index 0643826f8e87f12e6d14a8a3c69042d5cee93c51..d062e060b7eedd905de5c65e67855512313de2dc 100644
--- a/ios/chrome/browser/application_context.h
+++ b/ios/chrome/browser/application_context.h
@@ -50,7 +50,7 @@ class RapporServiceImpl;
}
namespace ukm {
-class UkmService;
+class UkmRecorder;
}
namespace variations {
@@ -103,8 +103,8 @@ class ApplicationContext {
// Gets the MetricsService used by this application.
virtual metrics::MetricsService* GetMetricsService() = 0;
- // Gets the UkmService used by this application.
- virtual ukm::UkmService* GetUkmService() = 0;
+ // Gets the UkmRecorder used by this application.
+ virtual ukm::UkmRecorder* GetUkmRecorder() = 0;
// Gets the VariationsService used by this application.
virtual variations::VariationsService* GetVariationsService() = 0;
« no previous file with comments | « components/ukm/ukm_source.h ('k') | ios/chrome/browser/application_context_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698